--[[
	Glyph Reporter
	
	Coded by Earl_Parvisjam

	This addon reports known and needed glyphs for all characters on the current server.
	
   ]]
   
GlyphReporter_Version = "1.3.1";
ReporterDB = {};
GR_Color = { ["name"] = "Red", ["r"] = 1, ["g"] = 0, ["b"] = 0 };
local realm = GetRealmName();
local player = UnitName("player");

---------------------------------------------------
-- OnLoad
---------------------------------------------------
function GlyphReporter_OnLoad(self)
	self:RegisterEvent("GLYPH_ENABLED");
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
	GlyphReporter_Print("Glyph Reporter v" ..GlyphReporter_Version .. " has been loaded successfully.");
end

---------------------------------------------------
-- OnEvent
---------------------------------------------------
function GlyphReporter_OnEvent(self, event)
	if (event == "PLAYER_ENTERING_WORLD") then
		if (ReporterDB[realm] == nil) then
			ReporterDB[realm] = {};
			ReporterDB[realm][player] = {};
			GR_ColorSelectButton_OnLoad(GR_ColorSelectButton);	
		end
		GlyphReporter_GrabCurrentData();
	end
end

---------------------------------------------------
-- GrabCurrentData
-- Summary:  Grabs all current Glyph info
---------------------------------------------------
function GlyphReporter_GrabCurrentData()
	local glyphList = {};
	if (GetNumGlyphs() > 0) then
		for index = 1, GetNumGlyphs() do
			local name, glyphType, isKnown, _, id, glyphLink = GetGlyphInfo(index);
			if (name ~= "header") then
				glyphList[id] = { ["Name"] = name, ["Type"] = glyphType, ["Known"] = isKnown };
			end	
		end
	end
	local Player = { ["Glyphs"] = glyphList };
	ReporterDB[realm][player] = Player;
end

---------------------------------------------------
-- CheckNeed
-- Summary:  Grabs all needy characters
---------------------------------------------------
local function GlyphReporter_CheckNeed(glyphId)
	GlyphReporter_GrabCurrentData();
	local needList = "Needed by:  ";
	local spellId = GlyphData[glyphId];
	for currentPlayer, value in pairs(ReporterDB[GetRealmName()]) do
		if (value["Glyphs"][spellId] ~= nil) and not(value["Glyphs"][spellId].Known) then				
				needList = needList ..currentPlayer;
		end
	end
	return needList;
end

---------------------------------------------------
-- GlyphReporter_Print
-- Summary:  A simple print wrapper mostly used in debugging
---------------------------------------------------
function GlyphReporter_Print(msg)
	if (msg == nil) then return; end
	if( DEFAULT_CHAT_FRAME ) then DEFAULT_CHAT_FRAME:AddMessage(msg, 1,1, 0); end
end

setOnce = {};
---------------------------------------------------
-- ToolTipHooker
-- Summary:  Hooks extra text onto the tooltip
---------------------------------------------------
local function ToolTipHooker(self, ...)
	local _, _, _, _, _, ItemType = GetItemInfo(43364);
	if (not setOnce[self]) then
		local itemLink = select(2, self:GetItem());
		if itemLink and GetItemInfo(itemLink) then	
			local _, itemId = strsplit(":", string.match(itemLink, "item[%-?%d:]+"));
			local itemName, _, _, _, _, itemType = GetItemInfo(itemLink);
			if (ItemType == itemType) then
				local list = GlyphReporter_CheckNeed(itemId);
				self:AddLine(list, GR_Color.r, GR_Color.g, GR_Color.b);
				setOnce[self] = true;
			end

		end
	end
end

---------------------------------------------------
-- ToolTipUnHooker
-- Summary:  Unhooks extra text on the tooltip
---------------------------------------------------
local function ToolTipUnhooker(self, ...)
	setOnce[self] = false;
end

GameTooltip:HookScript("OnTooltipSetItem", ToolTipHooker);
GameTooltip:HookScript("OnTooltipCleared", ToolTipUnhooker);

---------------------------------------------------
-- ***Interface Options Framework***
---------------------------------------------------

local colorList = { 
	["White"] = { ["r"] = 1, ["g"] = 1, ["b"] = 1,},
	["Yellow"] = { ["r"] = 1, ["g"] = 1, ["b"] = 0,},
	["Red"] = { ["r"] = 1, ["g"] = 0, ["b"] = 0,},
	["Green"] = { ["r"] = 0, ["g"] = 1, ["b"] = 0,},
	["Blue"] = { ["r"] = 0, ["g"] = 0, ["b"] = 1,},
}

---------------------------------------------------
-- GR_GUIFrame_OnLoad
---------------------------------------------------
function GR_GUIFrame_OnLoad(panel)
	panel.name = "Glyph Reporter";
	panel.okay = function (self) GR_ColorSelectButton_OnClick(); end;
	panel.cancel = function (self) GR_ColorSelectButton_Close(); end
	InterfaceOptions_AddCategory(panel);
end

---------------------------------------------------
-- GR_ColorSelect_OnLoad
---------------------------------------------------
function GR_ColorSelectButton_OnLoad(self)
	local info = UIDropDownMenu_CreateInfo();
	self.text = "Invalid";
	for k,v in pairs(colorList) do
	info.text = k;
	info.checked = false;
	if (k == GR_Color["name"]) then
		self.text = k;
		info.checked = true;
	end
	--info.r = v.r;
	--info.g = v.g;
	--info.b = v.b;
	--info.hasColorSwatch = true;
	info.func = function (self) GR_ColorClick(self); end;
	UIDropDownMenu_AddButton(info);
	UIDropDownMenu_SetText(self, self.text);
end
	self.text = UIDropDownMenu_GetSelectedName("GR_ColorSelectButton");
end

---------------------------------------------------
-- GR_ColorSelect_OnClick
---------------------------------------------------

local function GR_ColorSelectButton_OnClick(self)
	--UIDropDownMenu_SetText(self, self.value);
	ToggleDropDownMenu(1, nil, GR_ColorSelectButton, "GR_ColorSelectButton", 0, 0);
end

---------------------------------------------------
-- GR_ColorClick
-- Summary:  Action taken when the button is clicked
---------------------------------------------------
function GR_ColorClick(self)
	GR_Color.name = self.value;
	self.checked = true;
	GR_Color.r = colorList[self.value].r;
	GR_Color.g = colorList[self.value].g;
	GR_Color.b = colorList[self.value].b;
	ToggleDropDownMenu(1, nil, GR_ColorSelectButton, "GR_ColorSelectButton", 0, 1);
end

function GR_ColorSelectButton_Close(self)
	UIDropDownMenu_SetText(self, self.value);
end

GlyphData = {  --["itemID"] => glyphID
	--Death Knight
	["45804"] = 771, --Glyph of Death Coil
	["43546"] = 524, --Glyph of Icy Touch
	["43547"] = 525, --Glyph of Enduring Infection
	["45806"] = 773, --Glyph of Tranquil Grip
	["43826"] = 557, --Glyph of Outbreak
	["68793"] = 945, --Glyph of Dark Succor
	["43549"] = 527, --Glyph of Mind Freeze
	["43533"] = 512, --Glyph of Anti-Magic Shell
	["43550"] = 528, --Glyph of Army of the Dead
	["43534"] = 513, --Glyph of Unholy Frenzy
	["43551"] = 529, --Glyph of Foul Menagerie
	["43535"] = 514, --Glyph of Geist
	["43552"] = 530, --Glyph of Strangulate
	["43536"] = 515, --Glyph of Icebound Fortitude
	["43553"] = 531, --Glyph of Pillar of Frost
	["43537"] = 516, --Glyph of Chains of Ice
	["43554"] = 532, --Glyph of Vampiric Blood
	["43672"] = 553, --Glyph of Resilient Grip
	["43671"] = 554, --Glyph of Path of Frost
	["43539"] = 518, --Glyph of Death's Embrace
	["43542"] = 520, --Glyph of Death and Decay
	["43541"] = 519, --Glyph of Death Grip
	["43673"] = 555, --Glyph of Death Gate
	["45799"] = 768, --Glyph of Dancing Rune Weapon
	["43827"] = 558, --Glyph of Corpse Explosion
	["45800"] = 769, --Glyph of Dark Simulacrum
	["43825"] = 556, --Glyph of Unholy Command
	["43544"] = 522, --Glyph of Horn of Winter
	["43548"] = 526, --Glyph of Pestilence
	["43543"] = 521, --Glyph of Shifting Presences
	--Druid
	["40922"] = 179, --Glyph of Nature's Grasp
	["40923"] = 180, --Glyph of Savagery
	["40924"] = 181, --Glyph of Entangling Roots
	["89868"] = 1054, --Glyph of the Cheetah
	["43316"] = 431, --Glyph of Aquatic Form
	["43334"] = 432, --Glyph of the Chameleon
	["43335"] = 433, --Glyph of Charm Woodland Creature
	["45601"] = 671, --Glyph of Survival Instincts
	["45603"] = 673, --Glyph of Might of Ursoc
	["45622"] = 675, --Glyph of Cyclone
	["43674"] = 551, --Glyph of Dash
	["67484"] = 933, --Glyph of Fae Silence
	["67486"] = 935, --Glyph of The Predator
	["68039"] = 937, --Glyph of the Treant
	["40896"] = 161, --Glyph of Frenzied Regeneration
	["40897"] = 162, --Glyph of Maul
	["40899"] = 163, --Glyph of Solar Beam
	["40900"] = 164, --Glyph of the Stag
	["48720"] = 831, --Glyph of Ferocious Bite
	["40901"] = 165, --Glyph of Shred
	["40902"] = 166, --Glyph of Prowl
	["40903"] = 167, --Glyph of Pounce
	["40906"] = 168, --Glyph of Stampede
	["40908"] = 169, --Glyph of Innervate
	["40909"] = 170, --Glyph of Rebirth
	["67487"] = 936, --Glyph of Cat Form
	["40912"] = 171, --Glyph of Regrowth
	["40913"] = 172, --Glyph of Rejuvenation
	["45602"] = 672, --Glyph of Wild Growth
	["45604"] = 674, --Glyph of Stampeding Roar
	["40914"] = 173, --Glyph of Healing Touch
	["43331"] = 434, --Glyph of Blooming
	["40915"] = 174, --Glyph of Lifebloom
	["67485"] = 934, --Glyph of Faerie Fire
	["40916"] = 175, --Glyph of the Moonbeast
	["44922"] = 613, --Glyph of Stars
	["40919"] = 176, --Glyph of the Orca
	["43332"] = 435, --Glyph of Grace
	["40920"] = 177, --Glyph of Hurricane
	["44928"] = 631, --Glyph of Master Shapeshifter
	["40921"] = 178, --Glyph of Skull Bash
	["45623"] = 676, --Glyph of Barkskin
	--Hunter
	["42899"] = 353, --Glyph of Marked For Death
	["42900"] = 354, --Glyph of Mending
	["42901"] = 355, --Glyph of Distracting Shot
	["42902"] = 356, --Glyph of Endless Wrath
	["42903"] = 357, --Glyph of Deterrence
	["42904"] = 358, --Glyph of Disengage
	["42905"] = 359, --Glyph of Freezing Trap
	["42906"] = 360, --Glyph of Ice Trap
	["42907"] = 361, --Glyph of Misdirection
	["42908"] = 362, --Glyph of Explosive Trap
	["42909"] = 363, --Glyph of Animal Bond
	["42910"] = 364, --Glyph of No Escape
	["87278"] = 1050, --Glyph of Direction
	["42912"] = 366, --Glyph of Tame Beast
	["42913"] = 367, --Glyph of Snake Trap
	["42914"] = 368, --Glyph of Scattering
	["42915"] = 369, --Glyph of Mend Pet
	["42917"] = 371, --Glyph of Icy Solace
	["45625"] = 677, --Glyph of Chimera Shot
	["43338"] = 439, --Glyph of Revive Pet
	["43350"] = 440, --Glyph of Lesser Proportion
	["43351"] = 441, --Glyph of Fireworks
	["43356"] = 442, --Glyph of Stampede
	["43355"] = 443, --Glyph of Aspect of the Pack
	["45731"] = 691, --Glyph of Tranquilizing Shot
	["45733"] = 693, --Glyph of Master's Call
	["45735"] = 695, --Glyph of Mirrored Blades
	["85683"] = 1022, --Glyph of Aspect of the Beast
	["87279"] = 1051, --Glyph of Marking
	["87393"] = 1053, --Glyph of Fetch
	["85684"] = 1023, --Glyph of Black Ice 
	["42911"] = 365, --Glyph of Pathfinding
	["45732"] = 692, --Glyph of Aspect of the Cheetah
	["45734"] = 694, --Glyph of Scatter Shot
	["42898"] = 352, --Glyph of Camouflage
	["42897"] = 351, --Glyph of Aspects
	--Mage
	["45738"] = 698, --Glyph of Illusion
	["45740"] = 700, --Glyph of Deep Freeze
	["44955"] = 651, --Glyph of Arcane Power
	["63416"] = 923, --Glyph of Rapid Teleportation
	["42735"] = 312, --Glyph of Loose Mana
	["42736"] = 313, --Glyph of Arcane Explosion
	["42737"] = 314, --Glyph of Blink
	["42738"] = 315, --Glyph of Evocation
	["42739"] = 316, --Glyph of Combustion
	["42741"] = 318, --Glyph of Frost Nova
	["43339"] = 445, --Glyph of Porcupine
	["42743"] = 320, --Glyph of Momentum
	["42744"] = 321, --Glyph of Ice Block
	["42745"] = 322, --Glyph of Ice Lance
	["42746"] = 323, --Glyph of Cone of Cold
	["43361"] = 450, --Glyph of Penguin
	["43364"] = 451, --Glyph of Arcane Language
	["42749"] = 326, --Glyph of Mana Gem
	["42751"] = 328, --Glyph of Crittermorph
	["42752"] = 329, --Glyph of Polymorph
	["42753"] = 330, --Glyph of Icy Veins
	["42754"] = 331, --Glyph of Spellsteal
	["44920"] = 611, --Glyph of Remove Curse
	["63539"] = 928, --Glyph of Fire Blast
	["45739"] = 699, --Glyph of Mirror Image
	["50045"] = 871, --Glyph of Counterspell
	["43359"] = 448, --Glyph of Conjure Familiar
	["42748"] = 325, --Glyph of Invisibility
	["43360"] = 447, --Glyph of Monkey
	["45737"] = 697, --Glyph of Slow
	["43362"] = 449, --Glyph of Bear Cub
	["44684"] = 591, --Glyph of Frostfire Bolt
	["69773"] = 948, --Glyph of Armors
	["45736"] = 696, --Glyph of Water Elemental
	--Monk
	--To Be grabbed upon expansion
	--Paladin
	["45742"] = 702, --Glyph of Hammer of the Righteous
	["45744"] = 704, --Glyph of Alabaster Shield
	["45746"] = 706, --Glyph of Holy Shock
	["41092"] = 183, --Glyph of Double Jeopardy
	["41094"] = 184, --Glyph of Rebuke
	["41095"] = 185, --Glyph of Holy Wrath
	["41096"] = 186, --Glyph of Divine Protection
	["41097"] = 187, --Glyph of Templar's Verdict
	["80581"] = 986, --Glyph of Focused Wrath
	["85715"] = 986, --Glyph of Focused Wrath ????????????????????????????????
	["41098"] = 188, --Glyph of Avenging Wrath
	["41099"] = 189, --Glyph of Consecration
	["81956"] = 996, --Glyph of Battle Healer
	["85704"] = 996, --Glyph of Battle Healer ???????????????????????????????
	["41101"] = 191, --Glyph of Focused Shield
	["43869"] = 561, --Glyph of Immediate Truth
	["41102"] = 192, --Glyph of Turn Evil
	["41103"] = 193, --Glyph of Blinding Light
	["41104"] = 194, --Glyph of Final Wrath
	["45741"] = 701, --Glyph of Beacon of Light
	["45743"] = 703, --Glyph of Divine Storm
	["41106"] = 196, --Glyph of Illumination
	["45747"] = 707, --Glyph of Inquisition
	["41107"] = 197, --Glyph of Harsh Words
	["43366"] = 454, --Glyph of Winged Vengeance
	["43367"] = 455, --Glyph of Flash of Light
	["43368"] = 456, --Glyph of Seal of Blood
	["41109"] = 199, --Glyph of Light of Dawn
	["41110"] = 200, --Glyph of Blessed Life
	["80584"] = 987, --Glyph of Falling Avenger
	["85717"] = 987, --Glyph of Falling Avenger ???????????????????????????????
	["80586"] = 989, --Glyph of Bladed Judgment
	["85714"] = 989, --Glyph of Bladed Judgment ???????????????????????????????
	["43340"] = 453, --Glyph of The Mounted King
	["66918"] = 930, --Glyph of Protector of the Innocent
	["85716"] = 988, --Glyph of Righteous Retreat
	["41100"] = 190, --Glyph of Luminous Charger
	["43369"] = 457, --Glyph of Fire From the Heavens
	["43868"] = 560, --Glyph of Dazing Shield
	["43365"] = 452, --Glyph of Contemplation
	["41105"] = 195, --Glyph of Word of Glory
	["41108"] = 198, --Glyph of Divinity
	["83107"] = 1009, --Glyph of Mass Exorcism
	["85703"] = 1009, --Glyph of Mass Exorcism ???????????????????????????????
	["43867"] = 559, --Glyph of Denounce
	["45745"] = 705, --Glyph of Divine Plea
	--Priest
	["45753"] = 708, --Glyph of Dispersion
	["45756"] = 710, --Glyph of Penance
	["45758"] = 712, --Glyph of Mind Spike
	["87875"] = 1046, --Glyph of Lightspring
	["87902"] = 1046, --Glyph of Lightspring ?????????????????????????????????
	["42396"] = 251, --Glyph of Circle of Healing
	["42397"] = 252, --Glyph of Purify
	["42398"] = 253, --Glyph of Fade
	["42399"] = 254, --Glyph of Fear Ward
	["42400"] = 255, --Glyph of Inner Sanctum
	["79515"] = 1006, --Glyph of Vampiric Embrace
	["85707"] = 1006, --Glyph of Vampiric Embrace ????????????????????????????
	["42401"] = 256, --Glyph of Holy Nova
	["42402"] = 257, --Glyph of Inner Fire
	["42403"] = 258, --Glyph of Lightwell
	["42404"] = 259, --Glyph of Mass Dispel
	["42405"] = 260, --Glyph of Psychic Horror
	["42406"] = 261, --Glyph of Holy Fire
	["42407"] = 262, --Glyph of Inner Focus
	["42408"] = 263, --Glyph of Power Word: Shield
	["42409"] = 264, --Glyph of Spirit of Redemption
	["42410"] = 265, --Glyph of Psychic Scream
	["45760"] = 713, --Glyph of Desperation
	["42412"] = 267, --Glyph of Scourge Imprisonment
	["42414"] = 268, --Glyph of Mind Blast
	["42415"] = 269, --Glyph of Dispel Magic
	["43370"] = 459, --Glyph of Levitate
	["42417"] = 271, --Glyph of Prayer of Mending
	["43373"] = 461, --Glyph of Shackle Undead
	["43372"] = 462, --Glyph of Reflective Shield
	["43374"] = 463, --Glyph of Dark Archangel
	["87277"] = 1049, --Glyph of the Val'kyr
	["87392"] = 1052, --Glyph of Shadowy Friends
	["43342"] = 458, --Glyph of Shadow Ravens
	["77101"] = 961, --Glyph of Shadow
	["87276"] = 1048, --Glyph of Holy Resurrection
	["45755"] = 709, --Glyph of Leap of Faith
	["86541"] = 1047, --Glyph of Confession
	["43371"] = 460, --Glyph of Borrowed Time
	["79513"] = 1003, --Glyph of Mind Flay
	["85706"] = 1003, --Glyph of Mind Flay ???????????????????????????????????
	["79514"] = 1005, --Glyph of Shadow Word: Death
	["79538"] = 1007, --Glyph of Heavens
	["45757"] = 711, --Glyph of Dark Binding
	["42416"] = 270, --Glyph of Smite
	["42411"] = 266, --Glyph of Renew
	--Rogue
	["45761"] = 714, --Glyph of Vendetta
	["45767"] = 716, --Glyph of Stealth
	["45767"] = 732, --Glyph of Tricks of the Trade
	["45769"] = 734, --Glyph of Cloak of Shadows
	["64493"] = 929, --Glyph of Blind
	["43378"] = 467, --Glyph of Safe Fall
	["43377"] = 465, --Glyph of Pick Lock
	["45762"] = 715, --Glyph of Killing Spree
	["43376"] = 464, --Glyph of Distract
	["42967"] = 404, --Glyph of Hemorrhage
	["42954"] = 391, --Glyph of Shadow Walk
	["42955"] = 392, --Glyph of Ambush
	["42956"] = 393, --Glyph of Decoy
	["42957"] = 394, --Glyph of Blade Flurry
	["42958"] = 395, --Glyph of Crippling Poison
	["42959"] = 396, --Glyph of Recuperate
	["42960"] = 397, --Glyph of Evasion
	["42961"] = 398, --Glyph of Debilitation
	["42962"] = 399, --Glyph of Expose Armor
	["42963"] = 400, --Glyph of Feint
	["42964"] = 401, --Glyph of Garrote
	["45768"] = 733, --Glyph of Disguise
	["63420"] = 924, --Glyph of Vanish
	["42971"] = 926, --Glyph of Kick
	["42968"] = 405, --Glyph of Smoke Bomb
	["42969"] = 406, --Glyph of Cheap Shot
	["42970"] = 407, --Glyph of Sap
	["42965"] = 402, --Glyph of Detection
	["42972"] = 409, --Glyph of Adrenaline Rush
	["42973"] = 410, --Glyph of Shiv
	["42974"] = 411, --Glyph of Sprint
	["42966"] = 403, --Glyph of Gouge
	["43379"] = 468, --Glyph of Blurred Speed
	["43343"] = 466, --Glyph of Pick Pocket
	["43380"] = 469, --Glyph of Poisons
	["45766"] = 731, --Glyph of Deadly Momentum
	--Shaman
	["71155"] = 950, --Glyph of Unleashed Lightning
	["41541"] = 211, --Glyph of Water Shield
	["41517"] = 212, --Glyph of Unstable Earth
	["41518"] = 213, --Glyph of Chain Lightning
	["41524"] = 214, --Glyph of Spirit Walk
	["41526"] = 215, --Glyph of Capacitor Totem
	["41527"] = 216, --Glyph of Purge
	["41529"] = 217, --Glyph of Fire Elemental Totem
	["41530"] = 218, --Glyph of Fire Nova
	["41531"] = 219, --Glyph of Flame Shock
	["45771"] = 736, --Glyph of Feral Spirit
	["41532"] = 220, --Glyph of Wind Shear
	["41547"] = 221, --Glyph of Frost Shock
	["41533"] = 222, --Glyph of Healing Stream Totem
	["41534"] = 223, --Glyph of Healing Wave
	["45776"] = 752, --Glyph of Shamanistic Rage
	["45778"] = 754, --Glyph of Totemic Vigor
	["41537"] = 225, --Glyph of Lakestrider
	["41536"] = 226, --Glyph of Telluric Currents
	["41538"] = 227, --Glyph of Grounding Totem
	["41539"] = 228, --Glyph of Spiritwalker's Grace
	["41540"] = 229, --Glyph of Lava Lash
	["41552"] = 230, --Glyph of Chaining
	["41542"] = 231, --Glyph of Cleansing Waters
	["45770"] = 735, --Glyph of Thunder
	["45772"] = 737, --Glyph of Riptide
	["43725"] = 552, --Glyph of Ghost Wolf
	["43381"] = 470, --Glyph of Astral Recall
	["43386"] = 471, --Glyph of Spectral Wolf
	["43385"] = 473, --Glyph of Far Sight
	["43344"] = 474, --Glyph of Healing Storm
	["45777"] = 753, --Glyph of Hex
	["43388"] = 476, --Glyph of Totemic Encirclement
	["44923"] = 612, --Glyph of Thunderstorm
	["41535"] = 224, --Glyph of Totemic Recall
	["45775"] = 751, --Glyph of Deluge
	--Warlock
	["42471"] = 290, --Glyph of Carrion Swarm
	["42472"] = 291, --Glyph of Unstable Affliction
	["42473"] = 292, --Glyph of Falling Meteor
	["43394"] = 482, --Glyph of Soulwell
	["50077"] = 911, --Glyph of Everlasting Affliction
	["45780"] = 756, --Glyph of Demon Hunting
	["45782"] = 758, --Glyph of Demonic Circle
	["45785"] = 760, --Glyph of Life Tap
	["43391"] = 479, --Glyph of Eye of Kilrogg
	["42470"] = 289, --Glyph of Soulstone
	["45789"] = 761, --Glyph of Crimson Banish
	["45781"] = 757, --Glyph of Burning Embers
	["43393"] = 481, --Glyph of Enslave Demon
	["43392"] = 480, --Glyph of Curse of Exhaustion
	["42453"] = 272, --Glyph of Hand of Gul'dan
	["42454"] = 273, --Glyph of Conflagrate
	["42455"] = 274, --Glyph of Siphon Life
	["42456"] = 275, --Glyph of Verdant Spheres
	["42457"] = 276, --Glyph of Nightmares
	["42458"] = 277, --Glyph of Fear
	["42459"] = 278, --Glyph of Felguard
	["42460"] = 279, --Glyph of Demon Training
	["42461"] = 280, --Glyph of Health Funnel
	["42462"] = 281, --Glyph of Healthstone
	["42463"] = 282, --Glyph of Subtlety
	["42464"] = 283, --Glyph of Dark Soul
	["42465"] = 284, --Glyph of Imp Swarm
	["42466"] = 285, --Glyph of Soul Swap
	["42467"] = 286, --Glyph of Shadow Bolt
	["45779"] = 755, --Glyph of Soul Shards
	["43389"] = 477, --Glyph of Unending Breath
	["45783"] = 759, --Glyph of Shadowflame
	["43390"] = 478, --Glyph of Soul Consumption
	--Warrior
	["45792"] = 763, --Glyph of Death From Above
	["45794"] = 765, --Glyph of Intimidating Shout
	["45797"] = 767, --Glyph of Shield Wall
	["43395"] = 483, --Glyph of Mystic Shout
	["43396"] = 484, --Glyph of Bloodcurdling Shout
	["43397"] = 485, --Glyph of Long Charge
	["43398"] = 486, --Glyph of Gushing Wound
	["43399"] = 487, --Glyph of Unending Rage
	["43400"] = 488, --Glyph of Mighty Victory
	["43421"] = 489, --Glyph of Mortal Strike
	["43412"] = 490, --Glyph of Bloody Healing
	["43413"] = 491, --Glyph of Enraged Speed
	["43414"] = 492, --Glyph of Hindering Strikes
	["43415"] = 493, --Glyph of Heavy Repercussions
	["43416"] = 494, --Glyph of Bloodthirst
	["43417"] = 495, --Glyph of Rude Interruption
	["43418"] = 496, --Glyph of Gag Order
	["43419"] = 497, --Glyph of Blitz
	["43422"] = 499, --Glyph of Overpower
	["43423"] = 500, --Glyph of Hamstring
	["43424"] = 501, --Glyph of Hold the Line
	["43425"] = 502, --Glyph of Shield Slam
	["43427"] = 504, --Glyph of Hoarse Voice
	["43428"] = 505, --Glyph of Sweeping Strikes
	["43430"] = 507, --Glyph of Resonating Power
	["43431"] = 508, --Glyph of Victory Rush
	["43432"] = 509, --Glyph of Raging Wind
	["45790"] = 762, --Glyph of Whirlwind
	["45793"] = 764, --Glyph of Furious Sundering
	["45795"] = 766, --Glyph of Spell Reflection
	["85221"] = 1020, --Glyph of Blazing Trail
	["85722"] = 1020, --Glyph of Blazing Trail ?????????????????????
	["49084"] = 851, --Glyph of Thunder Strike
	["80588"] = 991, --Glyph of Burning Anger
	["85719"] = 991, --Glyph of Burning Anger ?????????????????????
	["67483"] = 932, --Glyph of Recklessness
	["80587"] = 990, --Glyph of Crow Feast
	["85720"] = 990, --Glyph of Crow Feast ????????????????
	["63481"] = 927, --Glyph of Colossus Smash
	["83096"] = 1008, --Glyph of Incite
	["85710"] = 1008, --Glyph of Incite ??????????????????????
	["67482"] = 931, --Glyph of Bull Rush
}
